
From: Geert Uytterhoeven <geert@linux-m68k.org>

M68k: Use #ifdef instead of #if (found by sparse)

Signed-off-by: Geert Uytterhoeven <geert@linux-m68k.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/m68k/kernel/signal.c    |    8 ++++----
 25-akpm/arch/m68k/kernel/traps.c     |   18 +++++++++---------
 25-akpm/arch/m68k/mm/memory.c        |    4 ++--
 25-akpm/include/asm-m68k/math-emu.h  |    2 +-
 25-akpm/include/asm-m68k/semaphore.h |   12 ++++++------
 5 files changed, 22 insertions(+), 22 deletions(-)

diff -puN arch/m68k/kernel/signal.c~m68k-sparse-if-vs-ifdef arch/m68k/kernel/signal.c
--- 25/arch/m68k/kernel/signal.c~m68k-sparse-if-vs-ifdef	2004-07-26 17:25:30.151392624 -0700
+++ 25-akpm/arch/m68k/kernel/signal.c	2004-07-26 17:25:30.165390496 -0700
@@ -349,7 +349,7 @@ restore_sigcontext(struct pt_regs *regs,
 		/*
 		 * user process trying to return with weird frame format
 		 */
-#if DEBUG
+#ifdef DEBUG
 		printk("user process returning with weird frame format\n");
 #endif
 		goto badframe;
@@ -450,7 +450,7 @@ rt_restore_ucontext(struct pt_regs *regs
 		/*
 		 * user process trying to return with weird frame format
 		 */
-#if DEBUG
+#ifdef DEBUG
 		printk("user process returning with weird frame format\n");
 #endif
 		goto badframe;
@@ -829,7 +829,7 @@ adjust_stack:
 	if (regs->stkadj) {
 		struct pt_regs *tregs =
 			(struct pt_regs *)((ulong)regs + regs->stkadj);
-#if DEBUG
+#ifdef DEBUG
 		printk("Performing stackadjust=%04x\n", regs->stkadj);
 #endif
 		/* This must be copied with decreasing addresses to
@@ -912,7 +912,7 @@ adjust_stack:
 	if (regs->stkadj) {
 		struct pt_regs *tregs =
 			(struct pt_regs *)((ulong)regs + regs->stkadj);
-#if DEBUG
+#ifdef DEBUG
 		printk("Performing stackadjust=%04x\n", regs->stkadj);
 #endif
 		/* This must be copied with decreasing addresses to
diff -puN arch/m68k/kernel/traps.c~m68k-sparse-if-vs-ifdef arch/m68k/kernel/traps.c
--- 25/arch/m68k/kernel/traps.c~m68k-sparse-if-vs-ifdef	2004-07-26 17:25:30.153392320 -0700
+++ 25-akpm/arch/m68k/kernel/traps.c	2004-07-26 17:25:30.167390192 -0700
@@ -541,7 +541,7 @@ static inline void bus_error030 (struct 
 	unsigned short ssw = fp->un.fmtb.ssw;
 	extern unsigned long _sun3_map_test_start, _sun3_map_test_end;
 
-#if DEBUG
+#ifdef DEBUG
 	if (ssw & (FC | FB))
 		printk ("Instruction fault at %#010lx\n",
 			ssw & FC ?
@@ -670,7 +670,7 @@ static inline void bus_error030 (struct 
 	unsigned short mmusr;
 	unsigned long addr, errorcode;
 	unsigned short ssw = fp->un.fmtb.ssw;
-#if DEBUG
+#ifdef DEBUG
 	unsigned long desc;
 
 	printk ("pid = %x  ", current->pid);
@@ -696,7 +696,7 @@ static inline void bus_error030 (struct 
 	if (ssw & DF) {
 		addr = fp->un.fmtb.daddr;
 
-#if DEBUG
+#ifdef DEBUG
 		asm volatile ("ptestr %3,%2@,#7,%0\n\t"
 			      "pmove %%psr,%1@"
 			      : "=a&" (desc)
@@ -708,7 +708,7 @@ static inline void bus_error030 (struct 
 #endif
 		mmusr = temp;
 
-#if DEBUG
+#ifdef DEBUG
 		printk("mmusr is %#x for addr %#lx in task %p\n",
 		       mmusr, addr, current);
 		printk("descriptor address is %#lx, contents %#lx\n",
@@ -767,7 +767,7 @@ static inline void bus_error030 (struct 
 				      : "a" (&tlong));
 			printk("tt1 is %#lx\n", tlong);
 #endif
-#if DEBUG
+#ifdef DEBUG
 			printk("Unknown SIGSEGV - 1\n");
 #endif
 			die_if_kernel("Oops",&fp->ptregs,mmusr);
@@ -812,7 +812,7 @@ static inline void bus_error030 (struct 
 		   should still create the ATC entry.  */
 		goto create_atc_entry;
 
-#if DEBUG
+#ifdef DEBUG
 	asm volatile ("ptestr #1,%2@,#7,%0\n\t"
 		      "pmove %%psr,%1@"
 		      : "=a&" (desc)
@@ -836,7 +836,7 @@ static inline void bus_error030 (struct 
 	else if (mmusr & (MMU_B|MMU_L|MMU_S)) {
 		printk ("invalid insn access at %#lx from pc %#lx\n",
 			addr, fp->ptregs.pc);
-#if DEBUG
+#ifdef DEBUG
 		printk("Unknown SIGSEGV - 2\n");
 #endif
 		die_if_kernel("Oops",&fp->ptregs,mmusr);
@@ -858,7 +858,7 @@ asmlinkage void buserr_c(struct frame *f
 	if (user_mode(&fp->ptregs))
 		current->thread.esp0 = (unsigned long) fp;
 
-#if DEBUG
+#ifdef DEBUG
 	printk ("*** Bus Error *** Format is %x\n", fp->ptregs.format);
 #endif
 
@@ -881,7 +881,7 @@ asmlinkage void buserr_c(struct frame *f
 #endif
 	default:
 	  die_if_kernel("bad frame format",&fp->ptregs,0);
-#if DEBUG
+#ifdef DEBUG
 	  printk("Unknown SIGSEGV - 4\n");
 #endif
 	  force_sig(SIGSEGV, current);
diff -puN arch/m68k/mm/memory.c~m68k-sparse-if-vs-ifdef arch/m68k/mm/memory.c
--- 25/arch/m68k/mm/memory.c~m68k-sparse-if-vs-ifdef	2004-07-26 17:25:30.154392168 -0700
+++ 25-akpm/arch/m68k/mm/memory.c	2004-07-26 17:25:30.167390192 -0700
@@ -129,7 +129,7 @@ int free_pointer_table (pmd_t *ptable)
 	return 0;
 }
 
-#if DEBUG_INVALID_PTOV
+#ifdef DEBUG_INVALID_PTOV
 int mm_inv_cnt = 5;
 #endif
 
@@ -179,7 +179,7 @@ unsigned long mm_ptov (unsigned long pad
 		voff += m68k_memory[i].size;
 	} while (++i < m68k_num_memory);
 
-#if DEBUG_INVALID_PTOV
+#ifdef DEBUG_INVALID_PTOV
 	if (mm_inv_cnt > 0) {
 		mm_inv_cnt--;
 		printk("Invalid use of phys_to_virt(0x%lx) at 0x%p!\n",
diff -puN include/asm-m68k/math-emu.h~m68k-sparse-if-vs-ifdef include/asm-m68k/math-emu.h
--- 25/include/asm-m68k/math-emu.h~m68k-sparse-if-vs-ifdef	2004-07-26 17:25:30.160391256 -0700
+++ 25-akpm/include/asm-m68k/math-emu.h	2004-07-26 17:25:30.168390040 -0700
@@ -102,7 +102,7 @@ struct fp_data {
 	struct fp_ext temp[2];
 };
 
-#if FPU_EMU_DEBUG
+#ifdef FPU_EMU_DEBUG
 extern unsigned int fp_debugprint;
 
 #define dprint(bit, fmt, args...) ({			\
diff -puN include/asm-m68k/semaphore.h~m68k-sparse-if-vs-ifdef include/asm-m68k/semaphore.h
--- 25/include/asm-m68k/semaphore.h~m68k-sparse-if-vs-ifdef	2004-07-26 17:25:30.161391104 -0700
+++ 25-akpm/include/asm-m68k/semaphore.h	2004-07-26 17:25:30.168390040 -0700
@@ -27,12 +27,12 @@ struct semaphore {
 	atomic_t count;
 	atomic_t waking;
 	wait_queue_head_t wait;
-#if WAITQUEUE_DEBUG
+#ifdef WAITQUEUE_DEBUG
 	long __magic;
 #endif
 };
 
-#if WAITQUEUE_DEBUG
+#ifdef WAITQUEUE_DEBUG
 # define __SEM_DEBUG_INIT(name) \
 		, (long)&(name).__magic
 #else
@@ -86,7 +86,7 @@ static inline void down(struct semaphore
 {
 	register struct semaphore *sem1 __asm__ ("%a1") = sem;
 
-#if WAITQUEUE_DEBUG
+#ifdef WAITQUEUE_DEBUG
 	CHECK_MAGIC(sem->__magic);
 #endif
 	might_sleep();
@@ -109,7 +109,7 @@ static inline int down_interruptible(str
 	register struct semaphore *sem1 __asm__ ("%a1") = sem;
 	register int result __asm__ ("%d0");
 
-#if WAITQUEUE_DEBUG
+#ifdef WAITQUEUE_DEBUG
 	CHECK_MAGIC(sem->__magic);
 #endif
 	might_sleep();
@@ -134,7 +134,7 @@ static inline int down_trylock(struct se
 	register struct semaphore *sem1 __asm__ ("%a1") = sem;
 	register int result __asm__ ("%d0");
 
-#if WAITQUEUE_DEBUG
+#ifdef WAITQUEUE_DEBUG
 	CHECK_MAGIC(sem->__magic);
 #endif
 
@@ -164,7 +164,7 @@ static inline void up(struct semaphore *
 {
 	register struct semaphore *sem1 __asm__ ("%a1") = sem;
 
-#if WAITQUEUE_DEBUG
+#ifdef WAITQUEUE_DEBUG
 	CHECK_MAGIC(sem->__magic);
 #endif
 
_
